@@ -39,6 +39,7 @@ class Browser:
 
         focus_title: to focus on a window that behaves like an app
         """
+        url = url.strip()
         cmd_to_run = self.open_shell_cmd(
             url, app_mode, incognito, browser, focus_title=focus_title
         )
@@ -77,13 +78,18 @@ class Browser:
 
         return self.fail_safe(url_expr)
 
+    def open_stdin(self):
+        import sys
+
+        self.open(sys.stdin.read())
+
     def _firefox(self, url: str):
         return "open -a Firefox {url}" if self._is_mac() else f"firefox {url}"
 
     def _chrome(self, url: str):
         if self._is_mac():
             if self._focus_title or self._app_mode:
-                send_notification(f"Open new chrome in app mode, can be a bit slow")
+                send_notification("Open new chrome in app mode, can be a bit slow")
 
                 return f"/Applications/Google\ Chrome.app/Contents/MacOS/Google\ Chrome --app={url}"
 
