@@ -1,4 +1,5 @@
 import os
+from python_search.apps.collect_input import CollectInput
 from python_search.apps.notification_ui import send_notification
 
 
@@ -12,6 +13,10 @@ class GoogleIt:
             url = content
 
         os.system(f'browser open "{url}"')
+    
+    def ask_then_search(self):
+        content = CollectInput().launch(name="Search Google", prefill_with_clipboard=True)
+        self.search(content)
 
 
 def main():
