@@ -1,8 +1,6 @@
 from __future__ import annotations
 
 import inspect
-import logging
-import os
 
 
 class EntriesGroup:
@@ -48,7 +46,7 @@ class EntriesGroup:
         result = {}
         class_name_tag = self.__class__.__name__
         for key, command in self.commands.items():
-            if type(command) is dict:
+            if isinstance(command, dict):
                 if "tags" not in command:
                     command["tags"] = [class_name_tag]
                 else:
@@ -74,4 +72,9 @@ class EntriesGroup:
 
         from python_search.configuration.loader import ConfigurationLoader
 
-        return ConfigurationLoader().get_project_root()
+        return ConfigurationLoader().get_entries_project_root()
+
+
+if __name__ == "__main__":
+    import fire
+    fire.Fire()
\ No newline at end of file
