@@ -4,9 +4,9 @@ import logging
 import subprocess
 from typing import Optional
 
-from python_search.apps.terminal import Terminal
-from python_search.core_entities.core_entities import Key
-from python_search.search.search_ui.kitty import get_kitty_cmd
+from python_search.apps.terminal import KittyTerminal
+from python_search.core_entities import Key
+from python_search.search.search_ui.kitty_for_search_ui import get_kitty_cmd
 
 
 class EntriesEditor:
@@ -14,6 +14,8 @@ class EntriesEditor:
     Open an ide to edit the entries
     """
 
+    ACK_PATH = '/opt/homebrew/bin/ack'
+
     def __init__(self, configuration=None):
         if not configuration:
             from python_search.configuration.loader import ConfigurationLoader
@@ -38,12 +40,12 @@ class EntriesEditor:
             return
 
         # needs to be case-insensitive search
-        cmd = f"ack -i '{key}' {self.configuration.get_project_root()} --py || true"
+        cmd = f"{EntriesEditor.ACK_PATH} -i '{key}' {self.configuration.get_project_root()} --python || true"
         logging.info(f"Command: {cmd}")
         result_shell = subprocess.check_output(cmd, shell=True, text=True)
 
         if not result_shell:
-            logging.info("Could not find match edit main file")
+            print("Could not find match edit main file, output: ", result_shell)
             self.edit_default()
             return
 
@@ -56,7 +58,7 @@ class EntriesEditor:
         import os
 
         os.system(
-            f"open -a pycharm '{self.configuration.get_project_root() + '/entries_main.py'}'"
+            f"kitty vim '{self.configuration.get_project_root() + '/entries_main.py'}'"
         )
 
     def _edit_file(self, file_name: str, line: Optional[int] = 30, dry_run=False):
@@ -66,9 +68,9 @@ class EntriesEditor:
 
         # @ todo make this editor generic
 
-        terminal = Terminal()
+        terminal = KittyTerminal()
         cmd: str = (
-            f" {get_kitty_cmd()} {terminal.GENERIC_TERMINAL_PARAMS} bash -c 'cd"
+            f" {terminal.get_kitty_cmd()} {terminal.GENERIC_TERMINAL_PARAMS} bash -c 'cd"
             f" {self.configuration.get_project_root()} "
             f"; {self._get_open_text_editor_command(file_name, line) }"
         )
@@ -83,14 +85,14 @@ class EntriesEditor:
         os.system(cmd)
 
     def _get_open_text_editor_command(self, file, line):
-        if self.configuration.get_text_editor() == "vim":
-            return f"{self.configuration.get_text_editor()} {file} +{line}'"
-        else:
-            # if is not a known editor just open the file
-            return f"{self.configuration.get_text_editor()} {file}'"
+        # vim only supported
+        return f"vim {file} +{line}'"
 
 
 def main():
     import fire
-
     fire.Fire(EntriesEditor)
+
+
+if __name__ == "__main__":
+    main()
