@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-
 from python_search.configuration.loader import ConfigurationLoader
 from python_search.entry_capture.filesystem_entry_inserter import (
     FilesystemEntryInserter,
@@ -59,7 +58,10 @@ class RegisterNew:
         Returns:
 
         """
+
         key = self._sanitize_key(key)
+        if not key:
+            raise Exception("Key is required")
 
         if not type:
             interpreter: BaseInterpreter = InterpreterMatcher.build_instance(
