@@ -1,12 +1,11 @@
 from __future__ import annotations
-
 import re
 import os
 from typing import List
 from datetime import datetime
 
 from python_search.configuration.loader import ConfigurationLoader
-from python_search.core_entities.core_entities import Key
+from python_search.core_entities import Key
 from python_search.interpreter.interpreter_matcher import InterpreterMatcher
 from python_search.logger import setup_run_key_logger
 from python_search.error.exception import notify_exception
@@ -73,7 +72,7 @@ class EntryRunner:
         )
 
         self._logger.info("Passed interpreter")
-        from python_search.events.run_performed import EntryExecuted
+        from python_search.events.run_performed.entity import EntryExecuted
         from python_search.events.run_performed.writer import LogRunPerformedClient
 
         run_performed = EntryExecuted(
