@@ -1,7 +1,7 @@
 from __future__ import annotations
 from typing import List, Union
-from python_search.config import DataConfig
-from python_search.data_collector import GenericDataCollector
+from python_search.configuration.data_config import DataConfig
+from python_search.events.data_collector import GenericDataCollector
 
 import uuid
 
@@ -29,7 +29,7 @@ class RankingGenerated(BaseModel):
         self.timestamp = str(datetime.datetime.now(datetime.timezone.utc).timestamp())
 
 
-class RankingGeneratedWriter:
+class RankingGeneratedEventWriter:
     def write(self, event: RankingGenerated):
         return GenericDataCollector().write(
             data=event.__dict__, table_name=EVENT_FOLDER
