@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from python_search.events.run_performed import EntryExecuted
+from python_search.events.run_performed.entity import EntryExecuted
 
 
 class LogRunPerformedClient:
@@ -38,7 +38,7 @@ class RunPerformedWriter:
 
         event.timestamp = str(datetime.datetime.now(datetime.timezone.utc).timestamp())
 
-        from python_search.data_collector import GenericDataCollector
+        from python_search.events.data_collector import GenericDataCollector
 
         return GenericDataCollector().write(
             data=event.__dict__, table_name="searches_performed"
