@@ -1,10 +1,13 @@
 import os
+import subprocess
+import sys
 from typing import Optional
 
 from python_search.apps.notification_ui import send_notification
-from python_search.apps.terminal import Terminal
+from python_search.apps.terminal import KittyTerminal
 from python_search.context import Context
 from python_search.exceptions import CommandDoNotMatchException
+from python_search.host_system.system_paths import SystemPaths
 from python_search.interpreter.base import BaseInterpreter
 from python_search.logger import setup_run_key_logger
 
@@ -23,7 +26,7 @@ class CmdInterpreter(BaseInterpreter):
         """ """
         self.context = context
 
-        if type(cmd) == str:
+        if isinstance(cmd, str):
             self.cmd = {WRAP_IN_TERMINAL: True, "cmd": cmd}
             return
 
@@ -60,7 +63,7 @@ class CmdInterpreter(BaseInterpreter):
         logger.info("Running it in a new terminal")
 
         hold_terminal = False if "not_hold_terminal" in self.cmd else True
-        cmd = Terminal().wrap_cmd_into_terminal(
+        cmd = KittyTerminal().wrap_cmd_into_terminal(
             cmd,
             title=self._get_window_title(),
             hold_terminal_open_on_end=hold_terminal,
@@ -82,12 +85,20 @@ class CmdInterpreter(BaseInterpreter):
     def _execute(self, cmd):
         logger.info(f"To run as subprocess: {cmd}")
 
-        import subprocess
-        import sys
+        env = os.environ
+        # add homebrew path to the path
+
+        env["PATH"] = "/opt/homebrew/bin:" + env["PATH"]
+        env["PATH"] = "/opt/miniconda3/envs/python312/bin:" + env["PATH"]
+        env["PATH"] = "/opt/miniconda3/envs/python313/bin:" + env["PATH"]
+        # add system path to the path
+        env["PATH"] = SystemPaths().BINARIES_PATH + ":" + env["PATH"]
 
         p = subprocess.Popen(
             cmd,
             shell=True,
+            # add path to the system path
+            env=env,
             stdin=None,
             stdout=sys.stdout,
             stderr=sys.stderr,
