@@ -1,7 +1,7 @@
 from typing import List
 
 from python_search.configuration.loader import ConfigurationLoader
-from python_search.core_entities.core_entities import Entry
+from python_search.core_entities import Entry
 
 
 class EntriesLoader:
@@ -30,18 +30,6 @@ class EntriesLoader:
 
         return json.dumps(result)
 
-    @staticmethod
-    def load_privacy_neutral_only() -> List[Entry]:
-        from python_search.privacy.privacy_detector import PrivacyDetector
-
-        detector = PrivacyDetector()
-
-        for i in EntriesLoader.load_all_entries():
-            if not detector.has_sentitive_content(
-                i.get_content_str()
-            ) and not detector.has_sentitive_content(i.key):
-                yield i
-
     @staticmethod
     def load_all_entries() -> List[Entry]:
         """
