@@ -1,6 +1,6 @@
 from typing import List
 import os
-from rank_bm25 import BM25Okapi as BM25
+from rank_bm25 import BM25Plus as BM25
 import nltk
 from python_search.entry_change import EntryChangeDetector
 
@@ -84,7 +84,7 @@ class Bm25Search:
             matches = self.bm25.get_top_n(
                 tokenized_query, self.entries, n=self.number_entries_to_return
             )
-        except:
+        except Exception:
             self.build_bm25()
             matches = self.bm25.get_top_n(
                 tokenized_query, self.entries, n=self.number_entries_to_return
