@@ -1,182 +1,171 @@
 import asyncio
+import os
 import sys
 from typing import Any
+import json
+import time
 
+from python_search.core_entities import Entry
+from python_search.search.search_ui.QueryLogic import QueryLogic
+from python_search.search.search_ui.search_actions import Actions
+from python_search.search.search_ui.search_utils import setup_datadog
+
+from python_search.apps.theme.theme import get_current_theme
+from python_search.host_system.system_paths import SystemPaths
+from python_search.logger import setup_term_ui_logger
+
+logger = setup_term_ui_logger()
 from getch import getch
 
-from python_search.search.search_ui.bm25_search import Bm25Search
-from python_search.search.search_ui.search_actions import Actions
-from python_search.search.search_ui.semantic_search import SemanticSearch
-
-from python_search.theme import get_current_theme
-from python_search.core_entities.core_entities import Entry
-from python_search.host_system.system_paths import SystemPaths
-
+startup_time = time.time_ns()
+statsd = setup_datadog()
 
+# disable hugging face warning about forking token paralelism when reloading entries
+os.environ["TOKENIZERS_PARALLELISM"] = 'false'
 class SearchTerminalUi:
-    MAX_LINE_SIZE = 80
-    MAX_KEY_SIZE = 45
-    MAX_CONTENT_SIZE = 45
-    NUMBER_ENTRIES_TO_RETURN = 10
+    MAX_KEY_SIZE = 35
+    MAX_CONTENT_SIZE = 46
+    RUN_KEY_EVENT = "python_search_run_key"
 
     _documents_future = None
     commands = None
     documents = None
-    ENABLE_SEMANTIC_SEARCH = True
 
     def __init__(self) -> None:
         self.theme = get_current_theme()
         self.cf = self.theme.get_colorful()
-        self.cf.update_palette(
-            {
-                "green": "#97AE5E",
-                "yellow": "#DB9D3E",
-                "red": "#E56B55",
-            }
-        )
         self.actions = Actions()
         self.previous_query = ""
+        self.typed_up_to_run = ""
         self.tdw = None
         self.reloaded = False
         self.first_run = True
 
         self._setup_entries()
+        self.normal_mode = False
 
     def run(self):
         """
         Rrun the application main loop
         """
-
-        self._hide_cursor()
+        statsd.increment("ps_run_triggered")
+        # hide cursor
+        print("\033[?25l", end="")
         self.query = ""
         self.selected_row = 0
         self.selected_query = -1
-        # hide cursor
-        while True:
-            self.print_first_line()
-            if self.query != self.previous_query or self.reloaded:
-                self.matches = self.search(query=self.query)
-                self.reloaded = False
-            self.previous_query = self.query
-            current_key = 0
-            self.matches = []
-            for key in self.search(self.query):
-                try:
-                    entry = Entry(key, self.commands[key])
-                except Exception:
-                    continue
-
-                if current_key == self.selected_row:
-                    self.print_highlighted(key, entry)
-                else:
-                    self.print_normal_row(key, entry)
-
-                current_key += 1
-                self.matches.append(key)
-
-            c = self.get_caracter()
-            self.process_chars(self.query, c)
-
-    def search(self, query):
-        """gets 1 from each type of search at a time and merge them to remove duplicates"""
-
-        already_returned = []
-        bm25_results = self.search_bm25.search(query)
-
-        semantic_results = []
-        if self.ENABLE_SEMANTIC_SEARCH and not self.first_run:
-            semantic_results = self.search_semantic.search(query)
-
-        for i in range(self.NUMBER_ENTRIES_TO_RETURN):
-            if (
-                bm25_results[i] not in already_returned
-                and bm25_results[i] in self.commands
-            ):
-                already_returned.append(bm25_results[i])
-                yield bm25_results[i]
-
-            if semantic_results and (
-                semantic_results[i] not in already_returned
-                and semantic_results[i] in self.commands
-            ):
-                already_returned.append(semantic_results[i])
-                yield semantic_results[i]
-
-            if len(already_returned) >= self.NUMBER_ENTRIES_TO_RETURN:
-                return
+        end_startup = time.time_ns()
+        duration_startup_seconds = (end_startup - startup_time) / 1000**3
+        statsd.histogram("ps_startup_no_render_seconds", duration_startup_seconds)
 
+        self.render()
         self.first_run = False
 
+        while True:
+            # blocking function call
+            c = self.get_caracter()
+            logger.info("processing char" + c)
+            self.process_chars(c)
+            self.render()
+            # sets query here
+            self.previous_query = self.query
+
+    @statsd.timed("ps_render")
+    def render(self):
+        self.print_first_line()
+        logger.info("rendering loop started")
+        current_key = 0
+        self.matched_keys = []
+
+        for key in self.search_logic.search(self.query):
+            try:
+                entry = Entry(key, self.commands[key])
+            except Exception:
+                entry = Entry(key, {"snippet": "Error loading entry"})
+
+            if current_key == self.selected_row:
+                self.print_highlighted(key, entry)
+            else:
+                self.print_normal_row(key, entry)
+
+            current_key += 1
+            self.matched_keys.append(key)
+        
     def _setup_entries(self):
         import subprocess
 
         output = subprocess.getoutput(
-            SystemPaths.BINARIES_PATH + "/pys _entries_loader load_entries_as_json "
+            SystemPaths.BINARIES_PATH + "/pys _entries_loader load_entries_as_json 2>/dev/null"
         )
-        import json
-
+        #print("output", output)
         self.commands = json.loads(output)
+        self.search_logic = QueryLogic(self.commands)
 
-        self.search_bm25 = Bm25Search(
-            self.commands, number_entries_to_return=self.NUMBER_ENTRIES_TO_RETURN
-        )
-        if self.ENABLE_SEMANTIC_SEARCH:
-            self.search_semantic = SemanticSearch(
-                self.commands, number_entries_to_return=self.NUMBER_ENTRIES_TO_RETURN
-            )
-
-    def _hide_cursor(self):
-        print("\033[?25l", end="")
 
     def get_caracter(self) -> str:
         try:
-            return getch()
+
+            logger.info("getting char")
+            c = getch()
+            return c
         except Exception:
             return " "
 
     def print_first_line(self):
+        if self.normal_mode:
+            content = self.cf.query_enabled("* " + self.query)
+        else:
+            content = self.cf.query(self.query)
+
         print(
             "\x1b[2J\x1b[H"
             + self.cf.cursor(f"({len(self.commands)})> ")
-            + f"{self.cf.bold(self.cf.query(self.query))}"
+            + f"{self.cf.bold(content)}"
         )
 
-    def process_chars(self, query: str, c: str):
+    def process_chars(self, c: str):
+        self.typed_up_to_run += c
         ord_c = ord(c)
         # test if the character is a delete (backspace)
         if ord_c == 127:
             # backspace
-            self.query = query[:-1]
+            self.query = self.query[:-1]
         elif ord_c == 10:
             # enter
-            self.actions.run_key(self.matches[self.selected_row])
-            if self.query:
-                self._get_data_warehouse().write_event(
-                    "python_search_typed_query", {"query": query}
-                )
+            self._run_key()
+        elif c in ["1", "2", "3", "4", "5", "6"] and self.normal_mode:
+            self.selected_row = int(c) - 1
+            self._run_key()
+        # elif ord_c == 27:
+        # swap between modes via esc
+        # self.normal_mode = not self.normal_mode
         elif ord_c == 9:
             # tab
-            self.actions.edit_key(self.matches[self.selected_row])
+            self.actions.edit_key(self.matched_keys[self.selected_row], block=True)
+            self._setup_entries()
+            self.reloaded = True
         elif c == "'":
             # tab
-            self.actions.copy_entry_value_to_clipboard(self.matches[self.selected_row])
+            self.actions.copy_entry_value_to_clipboard(
+                self.matched_keys[self.selected_row]
+            )
         elif ord_c == 47:
             # ?
             self.actions.search_in_google(self.query)
         # handle arrows
         elif ord_c == 66:
-            if self.selected_row < len(self.matches) - 1:
+            if self.selected_row < len(self.matched_keys) - 1:
                 self.selected_row = self.selected_row + 1
         elif ord_c == 65:
             if self.selected_row > 0:
                 self.selected_row = self.selected_row - 1
         elif c == ".":
             self.selected_query += 1
-            self.query = self.get_query(self.selected_query)
+            self.query = self.get_previously_used_query(self.selected_query)
         elif c == ",":
             if self.selected_query >= 0:
                 self.selected_query -= 1
-            self.query = self.get_query(self.selected_query)
+            self.query = self.get_previously_used_query(self.selected_query)
         elif c == "+":
             sys.exit(0)
         elif ord_c == 68 or c == ";":
@@ -184,12 +173,9 @@ class SearchTerminalUi:
             self.query = ""
         elif ord_c == 67:
             sys.exit(0)
-        elif ord_c == 92:
-            print("Reloading data...")
+        elif ord_c == 92 or c == ']':
             self._setup_entries()
-            self.query = ""
             self.reloaded = True
-            self.selected_row = 0
         elif c == "-":
             # go up and clear
             self.selected_row = 0
@@ -202,15 +188,28 @@ class SearchTerminalUi:
             self.query += c
             self.selected_row = 0
 
-    def get_query(self, position):
+    def _run_key(self):
+        self.actions.run_key(self.matched_keys[self.selected_row])
+        statsd.increment("ps_run_key")
+        self._get_data_warehouse().write_event(
+            self.RUN_KEY_EVENT,
+            {
+                "query": self.query,
+                "key": self.matched_keys[self.selected_row],
+                "type_sequence": self.typed_up_to_run,
+            },
+        )
+
+        statsd.gauge("ps_query_len_size", len(self.typed_up_to_run))
+        self.typed_up_to_run = ""
+
+    def get_previously_used_query(self, position) -> str:
         # len
-        df = self._get_data_warehouse().event("python_search_typed_query")
+        df = self._get_data_warehouse().event(self.RUN_KEY_EVENT)
         if position >= len(df):
             return ""
 
-        return df.sort_values(by="tdw_timestamp", ascending=False).iloc[position][
-            "query"
-        ]
+        return df.sort_values(by="tdw_timestamp", ascending=False).iloc[position]["key"]
 
     def _get_data_warehouse(self):
         if not self.tdw:
