@@ -2,7 +2,7 @@ from python_search.apps.window_manager import WindowManager
 from python_search.entries_group import EntriesGroup
 from python_search.environment import is_mac
 from python_search.shortcut.gnome import Gnome
-from python_search.shortcut.mac import Mac
+from python_search.shortcut.mac_karabiner_elements import MacKarabinerElements
 from python_search.shortcut.xfce import XFCE
 
 
@@ -13,7 +13,7 @@ class ShortcutGenerator:
 
     def __init__(self, configuration: EntriesGroup):
         self.configuration = configuration
-        self.mac = Mac(self.configuration)
+        self.mac = MacKarabinerElements(self.configuration)
         self.gnome = Gnome(self.configuration)
         self.xfce = XFCE(self.configuration)
 
